@@ -1,6 +1,7 @@
 package action
 
 import (
+	"context"
 	"sort"
 	"strings"
 
@@ -9,60 +10,66 @@ import (
 	"github.com/urfave/cli/v2"
 )
 
-type Build struct { //nolint:govet
+// Build is struct for running 'build' CLI command.
+type Build struct {
 	yml      *Yml
+	diff     *Diff
 	plandir  string
+	diffMode string
 	tags     cli.StringSlice
 	matchAll bool
 	autoYml  bool
 
-	diffMode string
-	diff     *Diff
 	// diffLive *DiffLive
 	// diffLocal *DiffLocalPlan
 }
 
-var (
-	diffModeLive  = "live"
-	diffModeLocal = "local"
+const (
+	// DiffModeLive is a subcommand name for diffing manifests in plan with actually running manifests in k8s.
+	DiffModeLive = "live"
+
+	// DiffModeLocal is a subcommand name for diffing manifests in two plans.
+	DiffModeLocal = "local"
 )
 
-func (i *Build) Run() error {
+// Run is main function for 'build' CLI command.
+func (i *Build) Run(ctx context.Context) (err error) {
 	if i.autoYml {
-		if err := i.yml.Run(); err != nil {
+		err = i.yml.Run(ctx)
+		if err != nil {
 			return err
 		}
 	}
 
 	newPlan := plan.New(i.plandir)
-	err := newPlan.Build(i.yml.file, i.normalizeTags(), i.matchAll)
+	err = newPlan.Build(ctx, i.yml.file, i.normalizeTags(), i.matchAll, i.yml.templater)
 	if err != nil {
 		return err
 	}
 
 	// Show current plan
-	newPlan.PrettyPlan()
+	newPlan.Logger().Info("🏗 Plan")
 
 	switch i.diffMode {
-	case diffModeLocal:
+	case DiffModeLocal:
 		oldPlan := plan.New(i.plandir)
 		if oldPlan.IsExist() {
 			log.Info("🆚 Diff with previous local plan")
-			if err := oldPlan.Import(); err != nil {
+			if err := oldPlan.Import(ctx); err != nil {
 				return err
 			}
 
 			newPlan.DiffPlan(oldPlan, i.diff.ShowSecret, i.diff.Wide)
 		}
 
-	case diffModeLive:
+	case DiffModeLive:
 		log.Info("🆚 Diff manifests in the kubernetes cluster")
-		newPlan.DiffLive(i.diff.ShowSecret, i.diff.Wide)
+		newPlan.DiffLive(ctx, i.diff.ShowSecret, i.diff.Wide, i.diff.ThreeWayMerge)
 	default:
-		log.Warnf("I dont know what is %q. I am skiping diff.", i.diffMode)
+		log.Warnf("I dont know what is %q diff mode. I am skiping diff.", i.diffMode)
 	}
 
-	err = newPlan.Export()
+	err = newPlan.Export(ctx)
 	if err != nil {
 		return err
 	}
@@ -75,6 +82,7 @@ func (i *Build) Run() error {
 	return nil
 }
 
+// Cmd returns 'build' *cli.Command.
 func (i *Build) Cmd() *cli.Command {
 	return &cli.Command{
 		Name:   "build",
@@ -84,6 +92,7 @@ func (i *Build) Cmd() *cli.Command {
 	}
 }
 
+// flags return flag set of CLI urfave.
 func (i *Build) flags() []cli.Flag {
 	// Init sub-structures
 	i.yml = &Yml{}
@@ -110,6 +119,7 @@ func (i *Build) flags() []cli.Flag {
 	return self
 }
 
+// normalizeTags is wrapper for normalizeTagList.
 func (i *Build) normalizeTags() []string {
 	return normalizeTagList(i.tags.Value())
 }
