@@ -1,6 +1,7 @@
 package action
 
 import (
+	"context"
 	"os"
 
 	"github.com/helmwave/helmwave/pkg/plan"
@@ -8,26 +9,31 @@ import (
 	"github.com/urfave/cli/v2"
 )
 
-type DiffLocalPlan struct { //nolint:govet
-	plandir1, plandir2 string
-	diff               *Diff
+// DiffLocalPlan is struct for running 'diff plan' command.
+type DiffLocalPlan struct {
+	diff     *Diff
+	plandir1 string
+	plandir2 string
 }
 
-func (d *DiffLocalPlan) Run() error {
+// Run is main function for 'diff plan' command.
+func (d *DiffLocalPlan) Run(ctx context.Context) error {
 	if d.plandir1 == d.plandir2 {
 		log.Warn(plan.ErrPlansAreTheSame)
 	}
 
-	plan1 := plan.New(d.plandir1)
-	if err := plan1.Import(); err != nil {
+	// Plan 1
+	plan1, err := plan.NewAndImport(ctx, d.plandir1)
+	if err != nil {
 		return err
 	}
 	if ok := plan1.IsManifestExist(); !ok {
 		return os.ErrNotExist
 	}
 
-	plan2 := plan.New(d.plandir2)
-	if err := plan2.Import(); err != nil {
+	// Plan 2
+	plan2, err := plan.NewAndImport(ctx, d.plandir2)
+	if err != nil {
 		return err
 	}
 	if ok := plan2.IsManifestExist(); !ok {
@@ -39,6 +45,7 @@ func (d *DiffLocalPlan) Run() error {
 	return nil
 }
 
+// Cmd returns 'diff plan' *cli.Command.
 func (d *DiffLocalPlan) Cmd() *cli.Command {
 	return &cli.Command{
 		Name:   "plan",
@@ -48,6 +55,7 @@ func (d *DiffLocalPlan) Cmd() *cli.Command {
 	}
 }
 
+// flags return flag set of CLI urfave.
 func (d *DiffLocalPlan) flags() []cli.Flag {
 	return []cli.Flag{
 		&cli.StringFlag{
